==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Kosongkan log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Segar semula</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Anda pasti mahu mengosongkan log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hari ini</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 hari</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 minggu</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 bulan</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 bulan</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksport</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kecemasan</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Awas</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikal</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Perhatian</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Nyahpepijat</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Daftar Masuk</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>But</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritikal</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKS (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Mengeksport...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Berjaya dieksport</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksport gagal</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksport Fail</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Tempoh:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Aras:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Senarai aplikasi:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Jenis Peristiwa:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Tindakan:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rekod but</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Rekod matikan</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rekod daftar masuk</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Nyahpepijat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kecemasan</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Awas</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikal</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Perhatian</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritikal</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Fail log kosong</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Pelihat Log</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Pelihat Log ialah sebuah alat berguna untuk melihat log-log sistem.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarikh dan Waktu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sumber</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Tindakan</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Jenis Peristiwa</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Aras:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proses:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarikh dan Waktu:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Maklumat:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nol</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarikh dan Waktu</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Log Sistem</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Log Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Log But</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Log dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Log Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Log Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Log Aplikasi</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Peristiwa But-Matikan</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Log dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Kosongkan log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Segar semula</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Anda pasti mahu mengosongkan log?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hari ini</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 hari</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 minggu</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 bulan</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 bulan</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kecemasan</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Awas</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikal</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Perhatian</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Nyahpepijat</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Daftar Masuk</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>But</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritikal</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Kenal pasti pengesahihan</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Kawalan Capaian Budi Bicara</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Kawalan capaian mandatori</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Jauh</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Audit dokumen</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Lain-lain</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKS (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Mengeksport...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Berjaya dieksport</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksport gagal</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksport Fail</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Tempoh:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Aras:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Jenis Peristiwa:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Tindakan:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rekod but</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Rekod matikan</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rekod daftar masuk</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Jenis Audit:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Nyahpepijat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Kecemasan</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Awas</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritikal</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Perhatian</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jejak</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritikal</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Fail log kosong</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Pelihat Log</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Pelihat Log ialah sebuah alat berguna untuk melihat log-log sistem.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Gelintar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Aras</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proses</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarikh dan Waktu</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Maklumat</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Pengguna</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sumber</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Tindakan</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Jenis Peristiwa</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nama pengguna</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Aras:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proses:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarikh dan Waktu:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Maklumat:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nol</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Pengguna:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nama Fail</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Masa Diubah Suai</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarikh dan Waktu</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Log Sistem</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Log Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Log But</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Log dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Log Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Log Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Log Aplikasi</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Peristiwa But-Matikan</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Log dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Log Lain</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Log Suai</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Log Audit</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Anda tiada keizinan untuk melihatnya</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Sela segar semula</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 saat</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Tiada segar semula</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksport semua</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Segar Semula Sekarang</translation>
    </message>
</context>
</TS>
